"use strict";
/* ============================================================================
 * Copyright (c) Palo Alto Networks
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 * ========================================================================== */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRequestBody = exports.hasProperties = exports.createRequestSchema = void 0;
const createDescription_1 = require("./createDescription");
const createSchema_1 = require("./createSchema");
const utils_1 = require("./utils");
function createRequestSchema({ title, body, ...rest }) {
    var _a;
    if (body === undefined ||
        body.content === undefined ||
        Object.keys(body).length === 0 ||
        Object.keys(body.content).length === 0) {
        return undefined;
    }
    // Get all MIME types, including vendor-specific
    const mimeTypes = Object.keys(body.content);
    if (mimeTypes && mimeTypes.length > 1) {
        return (0, utils_1.create)("MimeTabs", {
            schemaType: "request",
            children: mimeTypes.map((mimeType) => {
                const firstBody = body.content[mimeType].schema;
                const requestBodyProps = {
                    title,
                    description: body.description
                        ? (0, createDescription_1.createDescription)(body.description)
                        : null,
                    required: body.required,
                };
                const requestBodyDetails = getRequestBody(firstBody, requestBodyProps);
                return (0, utils_1.create)("TabItem", {
                    label: mimeType,
                    value: `${mimeType}`,
                    children: [requestBodyDetails],
                });
            }),
        });
    }
    const randomFirstKey = Object.keys(body.content)[0];
    const firstBody = (_a = body.content[randomFirstKey].schema) !== null && _a !== void 0 ? _a : body.content[randomFirstKey];
    const requestBodyProps = {
        title,
        description: body.description ? (0, createDescription_1.createDescription)(body.description) : null,
        required: body.required,
    };
    return getRequestBody(firstBody, requestBodyProps);
}
exports.createRequestSchema = createRequestSchema;
function hasProperties(obj) {
    return obj && obj.properties !== undefined;
}
exports.hasProperties = hasProperties;
function getRequestBody(firstBody, requestBodyProps) {
    if (firstBody === undefined) {
        return undefined;
    }
    // we don't show the table if there is no properties to show
    if (hasProperties(firstBody) && firstBody.properties !== undefined) {
        if (Object.keys(firstBody.properties).length === 0) {
            return undefined;
        }
    }
    let nodes = (0, createSchema_1.createNodes)(firstBody);
    if (typeof nodes === "string") {
        const content = nodes.trim();
        return ((0, utils_1.create)("RequestBodyDetailsBase", requestBodyProps) + `\n\n${content}\n\n`);
    }
    if (!Array.isArray(nodes)) {
        nodes = [nodes];
    }
    return (0, utils_1.create)("RequestBodyDetails", {
        ...requestBodyProps,
        data: nodes.filter(Boolean), // filter out any null or undefined values,
    });
}
exports.getRequestBody = getRequestBody;
