"use strict";
/* ============================================================================
 * Copyright (c) Palo Alto Networks
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 * ========================================================================== */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createResponseSchema = void 0;
const createDescription_1 = require("./createDescription");
// import { createDetails } from "./createDetails";
// import { createDetailsSummary } from "./createDetailsSummary";
const createRequestSchema_1 = require("./createRequestSchema");
// import { createNodes } from "./createSchema";
// import {
//   createExampleFromSchema,
//   createResponseExample,
//   createResponseExamples,
// } from "./createStatusCodes";
const utils_1 = require("./utils");
function createResponseSchema({ title, body, ...rest }) {
    if (body === undefined ||
        body.content === undefined ||
        Object.keys(body).length === 0 ||
        Object.keys(body.content).length === 0) {
        return undefined;
    }
    // Get all MIME types, including vendor-specific
    const mimeTypes = Object.keys(body.content);
    if (mimeTypes && mimeTypes.length) {
        return (0, utils_1.create)("MimeTabs", {
            schemaType: "response",
            children: mimeTypes.map((mimeType) => {
                var _a;
                const responseExamples = body.content[mimeType].examples;
                const responseExample = body.content[mimeType].example;
                const firstBody = (_a = body.content[mimeType].schema) !== null && _a !== void 0 ? _a : body.content[mimeType];
                if (firstBody === undefined &&
                    responseExample === undefined &&
                    responseExamples === undefined) {
                    return undefined;
                }
                const responseBody = (0, createRequestSchema_1.getRequestBody)(firstBody, {
                    title,
                    description: body.description
                        ? (0, createDescription_1.createDescription)(body.description)
                        : null,
                    required: false,
                });
                if (responseBody === undefined) {
                    return undefined;
                }
                return (0, utils_1.create)("TabItem", {
                    label: `${mimeType}`,
                    value: `${mimeType}`,
                    children: [
                        responseBody,
                        // create("SchemaTabs", {
                        // TODO: determine if we should persist this
                        // groupId: "schema-tabs",
                        // children: [
                        // firstBody &&
                        //   create("TabItem", {
                        //     label: `${title}`,
                        //     value: `${title}`,
                        //     children: [responseBody],
                        //   }),
                        // firstBody && createExampleFromSchema(firstBody, mimeType),
                        // responseExamples &&
                        //   createResponseExamples(responseExamples, mimeType),
                        // responseExample &&
                        //   createResponseExample(responseExample, mimeType),
                        // ],
                        // }),
                    ],
                });
            }),
        });
    }
    return undefined;
}
exports.createResponseSchema = createResponseSchema;
